/**
 * Example of use of ESP version of regular DHT library, available at https://github.com/beegee-tokyo/DHTesp/
 * Warning: DHT sensor must get 5V power, so the 3.3V from ESP32 does not work!
 * On some ESP modules, you can get 5V from the USB pin.
 * 
 * This example will just display the values of the sensor in the Serial Monitor (start it via Tools > Serial Monitor)
 * Make sure its speed is set to the same speed as specified with Serial.begin(...) in the first line in setup()
 */

#include <SPI.h>
#include <DHTesp.h>

// Initialize DHT sensor.
DHTesp dht;

void setup() {
  //Initialize serial and wait for port to open:
  Serial.begin(115200);
  while (!Serial) {} //wait for serial

  // initialize the DHT sensor
  // you might want to adjust the pin depending on the kind of esp module you use
  // I tested it with:
  // Adafruit ESP32 Feather - pin 21
  // Lolin32 Lite - pin 5
  dht.setup(5, DHTesp::DHT11); // configure it as a DHT11 on given pin
}

void loop() {
  // read sensor:
  TempAndHumidity newValues = dht.getTempAndHumidity();
      
  // Check if reads succesful, then print
  // Check if any reads failed and exit early (to try again).
  if (dht.getStatus() == 0) { // ok?
     Serial.println("DHT11 temperature=" + String(newValues.temperature) + " humidity=" + String(newValues.humidity));
  }
  else {
    Serial.println("DHT11 error status: " + String(dht.getStatusString()));
  }

  delay(10000); // wait 10 seconds
}
